@@ -9,7 +9,7 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light;
 {
-    $Riak::Light::VERSION = '0.083';
+    $Riak::Light::VERSION = '0.084';
 }
 ## use critic
 
@@ -182,7 +182,11 @@ sub get_all_indexes {
     state $check = compile( Any, Str, Str );
     my ( $self, $bucket, $key ) = $check->(@_);
     my $response = $self->_fetch( $bucket, $key, 0 );
-    ( defined $response ) ? $response->{indexes} : [];
+
+    return ( !defined $response )
+      ? []
+      : [ map { +{ value => $_->value, key => $_->key } }
+          @{ $response->{indexes} // [] } ];
 }
 
 sub exists {
@@ -518,19 +522,17 @@ sub _process_get_response {
 
     my $decoded_message = RpbGetResp->decode($encoded_message);
 
-    my $content = $decoded_message->content;
-    if ( ref($content) eq 'ARRAY' ) {
-        my $value        = $content->[0]->value;
-        my $indexes      = $content->[0]->indexes;
-        my $content_type = $content->[0]->content_type;
+    my $contents = $decoded_message->content;
+    if ( ref($contents) eq 'ARRAY' ) {
+        my $content = $contents->[0];
 
-        my $decode = $should_decode && ( $content_type eq 'application/json' );
+        my $decode =
+          $should_decode && ( $content->content_type eq 'application/json' );
         return {
-            value => ($decode) ? decode_json($value) : $value,
-            indexes => [
-                map { +{ value => $_->value, key => $_->key } }
-                  @{ $indexes // [] }
-            ]
+            value => ($decode)
+            ? decode_json( $content->value )
+            : $content->value,
+            indexes => $content->indexes,
         };
     }
 
@@ -589,7 +591,7 @@ Riak::Light - Fast and lightweight Perl client for Riak
 
 =head1 VERSION
 
-version 0.083
+version 0.084
 
 =head1 SYNOPSIS
 
